# UsageMetrics

A collection of usage metrics pertaining to resources owned by the Applications API
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**metrics** | [**list[UsageMetric]**](UsageMetric.md) | List of Usage metrics | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


